

While polynomials are also basic PDFs, they convey mathematically
a more special class of functions.

.. autosummary::
    :toctree: _generated/polynomials

    zfit.pdf.Chebyshev
    zfit.pdf.Legendre
    zfit.pdf.Chebyshev2
    zfit.pdf.Hermite
    zfit.pdf.Laguerre
    zfit.pdf.RecursivePolynomial
